# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ProjectListParams"]


class ProjectListParams(TypedDict, total=False):
    enrich: bool
    """Whether to include additional hosting metadata from Vercel"""

    limit: float
    """Maximum number of projects to return from each backing source"""
