# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev.types.database.v1 import (
    ProjectListResponse,
    ProjectCreateResponse,
    ProjectDeleteResponse,
    ProjectRetrieveResponse,
    ProjectCreateBranchResponse,
    ProjectListBranchesResponse,
    ProjectGetConnectionResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestProjects:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Casedev) -> None:
        project = client.database.v1.projects.create(
            name="litigation-docs-db",
        )
        assert_matches_type(ProjectCreateResponse, project, path=["response"])

    @parametrize
    def test_method_create_with_all_params(self, client: Casedev) -> None:
        project = client.database.v1.projects.create(
            name="litigation-docs-db",
            description="Production database for litigation document management",
            region="aws-us-east-1",
        )
        assert_matches_type(ProjectCreateResponse, project, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: Casedev) -> None:
        response = client.database.v1.projects.with_raw_response.create(
            name="litigation-docs-db",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert_matches_type(ProjectCreateResponse, project, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: Casedev) -> None:
        with client.database.v1.projects.with_streaming_response.create(
            name="litigation-docs-db",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert_matches_type(ProjectCreateResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: Casedev) -> None:
        project = client.database.v1.projects.retrieve(
            "id",
        )
        assert_matches_type(ProjectRetrieveResponse, project, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: Casedev) -> None:
        response = client.database.v1.projects.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert_matches_type(ProjectRetrieveResponse, project, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: Casedev) -> None:
        with client.database.v1.projects.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert_matches_type(ProjectRetrieveResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.database.v1.projects.with_raw_response.retrieve(
                "",
            )

    @parametrize
    def test_method_list(self, client: Casedev) -> None:
        project = client.database.v1.projects.list()
        assert_matches_type(ProjectListResponse, project, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Casedev) -> None:
        response = client.database.v1.projects.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert_matches_type(ProjectListResponse, project, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Casedev) -> None:
        with client.database.v1.projects.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert_matches_type(ProjectListResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: Casedev) -> None:
        project = client.database.v1.projects.delete(
            "id",
        )
        assert_matches_type(ProjectDeleteResponse, project, path=["response"])

    @parametrize
    def test_raw_response_delete(self, client: Casedev) -> None:
        response = client.database.v1.projects.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert_matches_type(ProjectDeleteResponse, project, path=["response"])

    @parametrize
    def test_streaming_response_delete(self, client: Casedev) -> None:
        with client.database.v1.projects.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert_matches_type(ProjectDeleteResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.database.v1.projects.with_raw_response.delete(
                "",
            )

    @parametrize
    def test_method_create_branch(self, client: Casedev) -> None:
        project = client.database.v1.projects.create_branch(
            id="id",
            name="staging",
        )
        assert_matches_type(ProjectCreateBranchResponse, project, path=["response"])

    @parametrize
    def test_method_create_branch_with_all_params(self, client: Casedev) -> None:
        project = client.database.v1.projects.create_branch(
            id="id",
            name="staging",
            parent_branch_id="branch_main_123",
        )
        assert_matches_type(ProjectCreateBranchResponse, project, path=["response"])

    @parametrize
    def test_raw_response_create_branch(self, client: Casedev) -> None:
        response = client.database.v1.projects.with_raw_response.create_branch(
            id="id",
            name="staging",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert_matches_type(ProjectCreateBranchResponse, project, path=["response"])

    @parametrize
    def test_streaming_response_create_branch(self, client: Casedev) -> None:
        with client.database.v1.projects.with_streaming_response.create_branch(
            id="id",
            name="staging",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert_matches_type(ProjectCreateBranchResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create_branch(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.database.v1.projects.with_raw_response.create_branch(
                id="",
                name="staging",
            )

    @parametrize
    def test_method_get_connection(self, client: Casedev) -> None:
        project = client.database.v1.projects.get_connection(
            id="id",
        )
        assert_matches_type(ProjectGetConnectionResponse, project, path=["response"])

    @parametrize
    def test_method_get_connection_with_all_params(self, client: Casedev) -> None:
        project = client.database.v1.projects.get_connection(
            id="id",
            branch="branch",
            pooled=True,
        )
        assert_matches_type(ProjectGetConnectionResponse, project, path=["response"])

    @parametrize
    def test_raw_response_get_connection(self, client: Casedev) -> None:
        response = client.database.v1.projects.with_raw_response.get_connection(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert_matches_type(ProjectGetConnectionResponse, project, path=["response"])

    @parametrize
    def test_streaming_response_get_connection(self, client: Casedev) -> None:
        with client.database.v1.projects.with_streaming_response.get_connection(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert_matches_type(ProjectGetConnectionResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get_connection(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.database.v1.projects.with_raw_response.get_connection(
                id="",
            )

    @parametrize
    def test_method_list_branches(self, client: Casedev) -> None:
        project = client.database.v1.projects.list_branches(
            "id",
        )
        assert_matches_type(ProjectListBranchesResponse, project, path=["response"])

    @parametrize
    def test_raw_response_list_branches(self, client: Casedev) -> None:
        response = client.database.v1.projects.with_raw_response.list_branches(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert_matches_type(ProjectListBranchesResponse, project, path=["response"])

    @parametrize
    def test_streaming_response_list_branches(self, client: Casedev) -> None:
        with client.database.v1.projects.with_streaming_response.list_branches(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert_matches_type(ProjectListBranchesResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list_branches(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.database.v1.projects.with_raw_response.list_branches(
                "",
            )


class TestAsyncProjects:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncCasedev) -> None:
        project = await async_client.database.v1.projects.create(
            name="litigation-docs-db",
        )
        assert_matches_type(ProjectCreateResponse, project, path=["response"])

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCasedev) -> None:
        project = await async_client.database.v1.projects.create(
            name="litigation-docs-db",
            description="Production database for litigation document management",
            region="aws-us-east-1",
        )
        assert_matches_type(ProjectCreateResponse, project, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCasedev) -> None:
        response = await async_client.database.v1.projects.with_raw_response.create(
            name="litigation-docs-db",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert_matches_type(ProjectCreateResponse, project, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCasedev) -> None:
        async with async_client.database.v1.projects.with_streaming_response.create(
            name="litigation-docs-db",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert_matches_type(ProjectCreateResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncCasedev) -> None:
        project = await async_client.database.v1.projects.retrieve(
            "id",
        )
        assert_matches_type(ProjectRetrieveResponse, project, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncCasedev) -> None:
        response = await async_client.database.v1.projects.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert_matches_type(ProjectRetrieveResponse, project, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncCasedev) -> None:
        async with async_client.database.v1.projects.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert_matches_type(ProjectRetrieveResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.database.v1.projects.with_raw_response.retrieve(
                "",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncCasedev) -> None:
        project = await async_client.database.v1.projects.list()
        assert_matches_type(ProjectListResponse, project, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCasedev) -> None:
        response = await async_client.database.v1.projects.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert_matches_type(ProjectListResponse, project, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCasedev) -> None:
        async with async_client.database.v1.projects.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert_matches_type(ProjectListResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncCasedev) -> None:
        project = await async_client.database.v1.projects.delete(
            "id",
        )
        assert_matches_type(ProjectDeleteResponse, project, path=["response"])

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncCasedev) -> None:
        response = await async_client.database.v1.projects.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert_matches_type(ProjectDeleteResponse, project, path=["response"])

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncCasedev) -> None:
        async with async_client.database.v1.projects.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert_matches_type(ProjectDeleteResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.database.v1.projects.with_raw_response.delete(
                "",
            )

    @parametrize
    async def test_method_create_branch(self, async_client: AsyncCasedev) -> None:
        project = await async_client.database.v1.projects.create_branch(
            id="id",
            name="staging",
        )
        assert_matches_type(ProjectCreateBranchResponse, project, path=["response"])

    @parametrize
    async def test_method_create_branch_with_all_params(self, async_client: AsyncCasedev) -> None:
        project = await async_client.database.v1.projects.create_branch(
            id="id",
            name="staging",
            parent_branch_id="branch_main_123",
        )
        assert_matches_type(ProjectCreateBranchResponse, project, path=["response"])

    @parametrize
    async def test_raw_response_create_branch(self, async_client: AsyncCasedev) -> None:
        response = await async_client.database.v1.projects.with_raw_response.create_branch(
            id="id",
            name="staging",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert_matches_type(ProjectCreateBranchResponse, project, path=["response"])

    @parametrize
    async def test_streaming_response_create_branch(self, async_client: AsyncCasedev) -> None:
        async with async_client.database.v1.projects.with_streaming_response.create_branch(
            id="id",
            name="staging",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert_matches_type(ProjectCreateBranchResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create_branch(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.database.v1.projects.with_raw_response.create_branch(
                id="",
                name="staging",
            )

    @parametrize
    async def test_method_get_connection(self, async_client: AsyncCasedev) -> None:
        project = await async_client.database.v1.projects.get_connection(
            id="id",
        )
        assert_matches_type(ProjectGetConnectionResponse, project, path=["response"])

    @parametrize
    async def test_method_get_connection_with_all_params(self, async_client: AsyncCasedev) -> None:
        project = await async_client.database.v1.projects.get_connection(
            id="id",
            branch="branch",
            pooled=True,
        )
        assert_matches_type(ProjectGetConnectionResponse, project, path=["response"])

    @parametrize
    async def test_raw_response_get_connection(self, async_client: AsyncCasedev) -> None:
        response = await async_client.database.v1.projects.with_raw_response.get_connection(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert_matches_type(ProjectGetConnectionResponse, project, path=["response"])

    @parametrize
    async def test_streaming_response_get_connection(self, async_client: AsyncCasedev) -> None:
        async with async_client.database.v1.projects.with_streaming_response.get_connection(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert_matches_type(ProjectGetConnectionResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get_connection(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.database.v1.projects.with_raw_response.get_connection(
                id="",
            )

    @parametrize
    async def test_method_list_branches(self, async_client: AsyncCasedev) -> None:
        project = await async_client.database.v1.projects.list_branches(
            "id",
        )
        assert_matches_type(ProjectListBranchesResponse, project, path=["response"])

    @parametrize
    async def test_raw_response_list_branches(self, async_client: AsyncCasedev) -> None:
        response = await async_client.database.v1.projects.with_raw_response.list_branches(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert_matches_type(ProjectListBranchesResponse, project, path=["response"])

    @parametrize
    async def test_streaming_response_list_branches(self, async_client: AsyncCasedev) -> None:
        async with async_client.database.v1.projects.with_streaming_response.list_branches(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert_matches_type(ProjectListBranchesResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list_branches(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.database.v1.projects.with_raw_response.list_branches(
                "",
            )
