# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["SkillCreateResponse"]


class SkillCreateResponse(BaseModel):
    content: Optional[str] = None

    created_at: Optional[datetime] = None

    metadata: Optional[object] = None

    name: Optional[str] = None

    slug: Optional[str] = None

    summary: Optional[str] = None

    tags: Optional[List[str]] = None

    version: Optional[int] = None
